@@ -30,11 +30,13 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 #
+
 """
 bzr vcs support.
 """
 
 
+from __future__ import absolute_import, print_function, unicode_literals
 import os
 import sys
 
@@ -49,7 +51,8 @@ except ImportError:
     from urllib2 import url2pathname
 
 from vcstools.vcs_base import VcsClientBase, VcsError
-from vcstools.common import sanitized, normalized_rel_path, run_shell_command
+from vcstools.common import sanitized, normalized_rel_path, \
+    run_shell_command, ensure_dir_notexists
 
 
 def _get_bzr_version():
@@ -130,17 +133,21 @@ class BzrClient(VcsClientBase):
     def checkout(self, url, version=None, verbose=False, shallow=False):
         if url is None or url.strip() == '':
             raise ValueError('Invalid empty url : "%s"' % url)
+        # bzr 2.5.1 fails if empty directory exists
+        if not ensure_dir_notexists(self.get_path()):
+            self.logger.error("Can't remove %s" % self.get_path())
+            return False
         cmd = 'bzr branch'
         if version:
             cmd += ' -r %s' % version
         cmd += ' %s %s' % (url, self._path)
-        value, _, _ = run_shell_command(cmd,
-                                        shell=True,
-                                        show_stdout=verbose,
-                                        verbose=verbose)
+        value, _, msg = run_shell_command(cmd,
+                                          shell=True,
+                                          show_stdout=verbose,
+                                          verbose=verbose)
         if value != 0:
-            if self.path_exists():
-                sys.stderr.write("Error: cannot checkout into existing directory\n")
+            if msg:
+                self.logger.error('%s' % msg)
             return False
         return True
 
