@@ -51,6 +51,7 @@ disambiguation, and in some cases warns.
 """
 
 
+from __future__ import absolute_import, print_function, unicode_literals
 import os
 import sys
 import gzip
@@ -174,13 +175,13 @@ class GitClient(VcsClientBase):
             if LooseVersion(self.gitversion) >= LooseVersion('1.7.10'):
                 cmd += ' --no-single-branch'
         cmd += ' --recursive %s %s' % (url, self._path)
-        value, _, _ = run_shell_command(cmd,
-                                        shell=True,
-                                        show_stdout=verbose,
-                                        verbose=verbose)
+        value, _, msg = run_shell_command(cmd,
+                                          shell=True,
+                                          show_stdout=verbose,
+                                          verbose=verbose)
         if value != 0:
-            if self.path_exists():
-                sys.stderr.write("Error: cannot checkout into existing directory\n")
+            if msg:
+                self.logger.error('%s' % msg)
             return False
 
         try:
