@@ -37,6 +37,7 @@ using ui object to redirect output into a string
 """
 
 
+from __future__ import absolute_import, print_function, unicode_literals
 import os
 import sys
 
@@ -145,9 +146,6 @@ class HgClient(VcsClientBase):
     def checkout(self, url, version='', verbose=False, shallow=False):
         if url is None or url.strip() == '':
             raise ValueError('Invalid empty url : "%s"' % url)
-        if self.path_exists():
-            sys.stderr.write("Error: cannot checkout into existing directory\n")
-            return False
         # make sure that the parent directory exists for #3497
         base_path = os.path.split(self.get_path())[0]
         try:
@@ -156,20 +154,22 @@ class HgClient(VcsClientBase):
             # OSError thrown if directory already exists this is ok
             pass
         cmd = "hg clone %s %s" % (sanitized(url), self._path)
-        value, _, _ = run_shell_command(cmd,
-                                        shell=True,
-                                        no_filter=True)
+        value, _, msg = run_shell_command(cmd,
+                                          shell=True,
+                                          no_filter=True)
         if value != 0:
-            if self.path_exists():
-                sys.stderr.write("Error: cannot checkout into existing directory\n")
+            if msg:
+                sys.logger.error('%s' % msg)
             return False
         if version is not None and version.strip() != '':
             cmd = "hg checkout %s" % sanitized(version)
-            value, _, _ = run_shell_command(cmd,
+            value, _, msg = run_shell_command(cmd,
                                             cwd=self._path,
                                             shell=True,
                                             no_filter=True)
             if value != 0:
+                if msg:
+                    sys.stderr.write('%s\n' % msg)
                 return False
         return True
 
