@@ -35,6 +35,7 @@ svn vcs support.
 """
 
 
+from __future__ import absolute_import, print_function, unicode_literals
 import os
 import sys
 
@@ -44,7 +45,8 @@ import dateutil.parser  # For parsing date strings
 import xml.dom.minidom  # For parsing logfiles
 
 from vcstools.vcs_base import VcsClientBase, VcsError
-from vcstools.common import sanitized, normalized_rel_path, run_shell_command
+from vcstools.common import sanitized, normalized_rel_path, \
+    run_shell_command, ensure_dir_notexists
 
 
 def _get_svn_version():
@@ -100,15 +102,14 @@ class SvnClient(VcsClientBase):
 
     def detect_presence(self):
         return self.path_exists() and \
-               os.path.isdir(os.path.join(self._path, '.svn'))
+               os.path.isdir(os.path.join(self.get_path(), '.svn'))
 
     def checkout(self, url, version='', verbose=False, shallow=False):
         if url is None or url.strip() == '':
             raise ValueError('Invalid empty url : "%s"' % url)
-        # Need to check as SVN does not care
-        if self.path_exists():
-            sys.stderr.write("Error: cannot checkout into existing "
-                           + "directory %s\n" % self._path)
+        # Need to check as SVN 1.6.17 writes into directory even if not empty
+        if not ensure_dir_notexists(self.get_path()):
+            self.logger.error("Can't remove %s" % self.get_path())
             return False
         if version is not None and version != '':
             if not version.startswith("-r"):
@@ -118,12 +119,14 @@ class SvnClient(VcsClientBase):
         cmd = 'svn co %s %s %s' % (sanitized(version),
                                    sanitized(url),
                                    self._path)
-        value, _, _ = run_shell_command(cmd,
-                                        shell=True,
-                                        no_filter=True)
-        if value == 0:
-            return True
-        return False
+        value, _, msg = run_shell_command(cmd,
+                                          shell=True,
+                                          no_filter=True)
+        if value != 0:
+            if msg:
+                self.logger.error('%s' % msg)
+            return False
+        return True
 
     def update(self, version=None, verbose=False):
         if not self.detect_presence():
