@@ -39,6 +39,7 @@ tarfile with a folder inside for each version.
 """
 
 
+from __future__ import absolute_import, print_function, unicode_literals
 import os
 import tempfile
 import shutil
@@ -46,20 +47,7 @@ import tarfile
 import sys
 import yaml
 from vcstools.vcs_base import VcsClientBase, VcsError
-
-# first try python3, then python2
-try:
-    from urllib.request import urlretrieve
-except ImportError:
-    # from urllib import urlretrieve # malfunctions behind proxy
-    import urllib2
-    def urlretrieve(url):
-        fdesc, fname = tempfile.mkstemp() # Make a temporary file
-        fhand = os.fdopen(fdesc, "w")
-        resp = urllib2.urlopen(url)
-        shutil.copyfileobj(resp.fp, fhand) # Copy the http response to the temporary file.
-        return (fname, resp.headers)
-
+from vcstools.common import urlretrieve_netrc, ensure_dir_notexists
 
 
 __pychecker__ = 'unusednames=spec'
@@ -105,8 +93,8 @@ class TarClient(VcsClientBase):
         checkout named *.tar which is a yaml file listing origin url
         and version arguments.
         """
-        if self.path_exists():
-            self.logger.error("Cannot checkout into existing directory")
+        if not ensure_dir_notexists(self.get_path()):
+            self.logger.error("Can't remove %s" % self.get_path())
             return False
         tempdir = None
         result = False
@@ -115,7 +103,7 @@ class TarClient(VcsClientBase):
             if os.path.isfile(url):
                 filename = url
             else:
-                (filename, _) = urlretrieve(url)
+                (filename, _) = urlretrieve_netrc(url)
                 # print "filename", filename
             temp_tarfile = tarfile.open(filename, 'r:*')
             members = None # means all members in extractall
