@@ -31,7 +31,7 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-from __future__ import unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 import os
 import io
@@ -139,6 +139,15 @@ class GitClientTest(GitClientTestSetups):
         self.assertEqual(client.get_branch_parent(), "master")
         #self.assertEqual(client.get_version(), '-r*')
 
+    def test_checkout_dir_exists(self):
+        url = self.remote_path
+        client = GitClient(self.local_path)
+        self.assertFalse(client.path_exists())
+        os.makedirs(self.local_path)
+        self.assertTrue(client.checkout(url))
+        # non-empty
+        self.assertFalse(client.checkout(url))
+
     def test_checkout_no_unnecessary_updates(self):
         client = GitClient(self.local_path)
         client.fetches = 0
